@@ -181,11 +181,17 @@ class SQLCli(object):
             if os.path.isfile(os.path.join(os.environ["SQLCLI_HOME"], "profile", "default")):
                 self.profile.append(os.path.join(os.environ["SQLCLI_HOME"], "profile", "default"))
         if profile is not None:
-            if os.path.isfile(profile):
-                self.profile.append(profile)
+            # os.path.isfile 不能检查带有单引号的文件信息，所以这里检查的时候不包含单引号
+            # start 实际执行的时候需要有单引号，不然由于空格或者其他字符可能会导致SQL文件名称被分裂
+            if str(profile).startswith("'") and str(profile).endswith("'"):
+                m_Profile = str(profile)[1:-1]
+            else:
+                m_Profile = str(profile).strip()
+            if os.path.isfile(m_Profile):
+                self.profile.append(str(profile))
             else:
                 if "SQLCLI_DEBUG" in os.environ:
-                    print("Profile does not exist ! Will ignore it. [" + str(os.path.abspath(profile)) + "]")
+                    print("Profile does not exist ! Will ignore it. [" + m_Profile + "]")
         if "SQLCLI_DEBUG" in os.environ:
             for m_Profile in self.profile:
                 print("Profile = [" + str(m_Profile) + "]")
@@ -634,7 +640,7 @@ class SQLCli(object):
 
         # 如果连接内容仅仅就一个mem，则连接到内置的memory db
         if arg.strip().upper() == "MEM":
-            arg = "X/X@jdbc:h2:mem://0.0.0.0:0/X"
+            arg = "X/X@jdbc:h2mem:mem://0.0.0.0:0/X"
 
         # 分割字符串，可能用单引号或者双引号包括, 单词中不能包含分割符
         # -- 1 首先找到@符号
@@ -1079,7 +1085,14 @@ class SQLCli(object):
                 "status": "Session restored Successful."
             }
             return
-        m_SQLFileList = str(arg).split()
+
+        # 分割字符串，考虑SQL文件名中包含空格的问题
+        temp1 = str(arg).strip()
+        temp1 = shlex.shlex(temp1)
+        temp1.whitespace = ' '
+        temp1.whitespace_split = True
+        m_SQLFileList = list(temp1)
+
         m_nLoop = 1
         if len(m_SQLFileList) >= 3 and \
                 m_SQLFileList[len(m_SQLFileList) - 2].lower() == 'loop' and \
@@ -1089,9 +1102,17 @@ class SQLCli(object):
         for m_curLoop in range(0, m_nLoop):
             for m_SQLFile in m_SQLFileList:
                 try:
+                    if str(m_SQLFile).startswith("'"):
+                        m_SQLFile = m_SQLFile[1:]
+                    if str(m_SQLFile).endswith("'"):
+                        m_SQLFile = m_SQLFile[:-1]
                     with open(os.path.expanduser(m_SQLFile), encoding=cls.Client_Charset) as f:
                         query = f.read()
 
+                    # 空文件直接返回
+                    if len(query) == 0:
+                        continue
+
                     # 处理NLS文档头数据
                     if ord(query[0]) == 0xFEFF:
                         # 去掉SQL文件可能包含的UTF-BOM
@@ -1834,12 +1855,19 @@ class SQLCli(object):
             for m_nPos in range(0, len(m_Row)):
                 if m_Row[m_nPos] is None:
                     # 空值打印为<null>
-                    m_ColumnLength[m_nPos] = len('<null>')
+                    if m_ColumnLength[m_nPos] < len('<null>'):
+                        m_ColumnLength[m_nPos] = len('<null>')
                 elif isinstance(m_Row[m_nPos], str):
-                    for m_iter in m_Row[m_nPos].split('\n'):
-                        if len(m_iter) + wide_chars(m_iter) > m_ColumnLength[m_nPos]:
-                            # 为了保持长度一致，长度计算的时候扣掉中文的显示长度
-                            m_ColumnLength[m_nPos] = len(m_iter) + wide_chars(m_iter)
+                    m_PrintValue = m_Row[m_nPos]
+                    m_PrintValue = m_PrintValue.replace('\n', '\\n').replace('\r', '\\r').replace('\t', '\\t')
+                    # m_PrintValue = repr(m_Row[m_nPos]
+                    # if m_PrintValue.startswith("'") and m_PrintValue.endswith("'"):
+                    #     m_PrintValue = m_PrintValue[1:-1]
+                    # elif m_PrintValue.startswith('"') and m_PrintValue.endswith('"'):
+                    #     m_PrintValue = m_PrintValue[1:-1]
+                    if len(m_PrintValue) + wide_chars(m_PrintValue) > m_ColumnLength[m_nPos]:
+                        # 为了保持长度一致，长度计算的时候扣掉中文的显示长度
+                        m_ColumnLength[m_nPos] = len(m_PrintValue) + wide_chars(m_PrintValue)
                 else:
                     if len(str(m_Row[m_nPos])) + wide_chars(m_Row[m_nPos]) > m_ColumnLength[m_nPos]:
                         m_ColumnLength[m_nPos] = len(str(m_Row[m_nPos])) + wide_chars(m_Row[m_nPos])
@@ -1860,39 +1888,22 @@ class SQLCli(object):
         # 打印字段内容
         m_RowNo = 0
         for m_Row in cur:
-            m_RowNo = m_RowNo + 1
-            # 首先计算改行应该打印的高度（行中的内容可能右换行符号）
-            m_RowHeight = 1
-            for m_nPos in range(0, len(m_Row)):
-                if isinstance(m_Row[m_nPos], str):
-                    if len(m_Row[m_nPos].split('\n')) > m_RowHeight:
-                        m_RowHeight = len(m_Row[m_nPos].split('\n'))
-            # 首先构造一个空的结果集，行数为计划打印的行高
             m_output = []
-            if m_RowHeight == 1:
-                m_output.append(m_Row)
-            else:
-                for m_iter in range(0, m_RowHeight):
-                    m_output.append(())
-                # 依次填入数据
-                for m_nPos in range(0, len(m_Row)):
-                    m_SplitRow = ()
-                    if isinstance(m_Row[m_nPos], str):
-                        m_SplitColumnValue = m_Row[m_nPos].split('\n')
-                    else:
-                        m_SplitColumnValue = [m_Row[m_nPos], ]
-                    for m_iter in range(0, m_RowHeight):
-                        if len(m_SplitColumnValue) > m_iter:
-                            if str(m_SplitColumnValue[m_iter]).endswith('\r'):
-                                m_SplitColumnValue[m_iter] = m_SplitColumnValue[m_iter][:-1]
-                            m_output[m_iter] = m_output[m_iter] + (m_SplitColumnValue[m_iter],)
-                        else:
-                            m_output[m_iter] = m_output[m_iter] + ("",)
+            m_output.append(m_Row)
             for m_iter in m_output:
                 m_TableContentLine = '|'
                 for m_nPos in range(0, len(m_iter)):
                     if m_iter[m_nPos] is None:
                         m_PrintValue = '<null>'
+                    elif isinstance(m_iter[m_nPos], str):
+                        m_PrintValue = m_Row[m_nPos]
+                        m_PrintValue = m_PrintValue.replace('\n', '\\n').replace('\r', '\\r').replace('\t', '\\t')
+                        #
+                        # m_PrintValue = repr(m_iter[m_nPos])
+                        # if m_PrintValue.startswith("'") and m_PrintValue.endswith("'"):
+                        #     m_PrintValue = m_PrintValue[1:-1]
+                        # elif m_PrintValue.startswith('"') and m_PrintValue.endswith('"'):
+                        #     m_PrintValue = m_PrintValue[1:-1]
                     else:
                         m_PrintValue = str(m_iter[m_nPos])
                     # 所有内容字符串左对齐
@@ -1930,7 +1941,8 @@ class SQLCli(object):
             for m_nPos in range(0, len(m_Row)):
                 if m_Row[m_nPos] is None:
                     # 空值打印为<null>
-                    m_ColumnLength[m_nPos] = len('<null>')
+                    if m_ColumnLength[m_nPos] < len('<null>'):
+                        m_ColumnLength[m_nPos] = len('<null>')
                 elif isinstance(m_Row[m_nPos], str):
                     for m_iter in m_Row[m_nPos].split('\n'):
                         if len(m_iter) + wide_chars(m_iter) > m_ColumnLength[m_nPos]:
